import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { useUsMap } from './useUsMap';
import { useCities } from './useCities';
import { Marks } from './Marks';
import { ColorLegend } from './ColorLegend';
import { csv, scaleSqrt, scaleOrdinal, max, format, extent, scaleLinear, arc, nest, pie,descending, ascending } from 'd3';

const width = 960;
const height = 500;
const margin = { top: 20, right: 250, bottom: 65, left: 90 };
const xAxisLabelOffset = 45;
const yAxisLabelOffset = 20;
const fadeOpacity = 0.2;
const circleRadius = 6;
const legendOffset = 185;
const centerX = width / 2;
const centerY = height / 2;

const App = () => {
  const usMap = useUsMap();
  let cities = useCities();
  const [hoveredValue, setHoveredValue] = useState(null);
  
  if (!usMap || !cities) {
    return <pre>Loading...</pre>;
  }


  
  const sizeValue = d => d.IngredientCount;
  const maxRadius = 10;

  const sizeScale = scaleSqrt()
    .domain([0, max(cities, sizeValue)])
    .range([0, maxRadius]);
  
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xValue = d => d.Longitude;
  const yValue = d => d.Latitude;
  
  const colorValue = d => d.Ingredient;
	const colorLegendLabel = 'Ingredients';

  const filteredData = cities.filter(d => hoveredValue === colorValue(d));

  const xScale = scaleLinear()
    .domain(extent(cities, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(cities, yValue))
    .range([0, innerHeight]);
  
  const color = ['#a6cee3','#1f78b4','#b2df8a','#33a02c','#fb9a99','#e31a1c','#fdbf6f','#ff7f00','#cab2d6','#6a3d9a']

  const colorScale = scaleOrdinal()
    .domain(cities.map(colorValue))
    .range(color);

  console.log(setHoveredValue);
  console.log(cities[0]);
  
   
  console.log("hi");

  const ny = pie()
			.value(function value(d) {return d.IngredientCount})
  		(cities
       .filter(d => d.Location =="New York")
       .slice(0,10));
  
  console.log(ny);

  const tooltipIngredient = d => d['data']['key'];
  const tooltipCount = d => d['data']['value'];
  
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${innerWidth + legendOffset}, 60)`}>
          <text x={xAxisLabelOffset} y={-yAxisLabelOffset} className="axis-label" textAnchor="middle">
          {colorLegendLabel}
          </text>
          <ColorLegend
            tickSpacing={22}
            tickSize={10}
            tickTextOffset={12}
            tickSize={circleRadius}
            colorScale={colorScale}
            onHover={setHoveredValue}
            hoveredValue={hoveredValue}
            fadeOpacity={fadeOpacity}
          />
        </g>
      <g transform={`translate(-70, 0)`}>
      <g opacity={hoveredValue ? fadeOpacity : 1}>
      	<Marks 
        usMap={usMap} cities = {ny}
        sizeScale={sizeScale}
        sizeValue={sizeValue}
  			colorScale={colorScale}
  			colorValue={colorValue}
          />
      </g>
      	<Marks 
        usMap={usMap} cities = {ny}
        sizeScale={sizeScale}
        sizeValue={sizeValue}
  			colorScale={colorScale}
  			colorValue={colorValue}
          />
      </g>
        ))
        };
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
